| Safe Haskell | None |
|---|
Propellor
Description
Pulls in lots of useful modules for building Properties.
propellor-0.1: property-based host configuration management in haskell
| Safe Haskell | None |
|---|
Propellor
Description
Pulls in lots of useful modules for building Properties.